@@ -10,8 +10,16 @@
 //! [pqc]: https://github.com/pqclean/pqclean/
 //!
 
+#![no_std]
 #![allow(clippy::len_without_is_empty)]
 
+// For no-std vectors
+extern crate alloc;
+
+// For tests
+#[cfg(feature = "std")]
+extern crate std;
+
 pub mod ffi;
 pub mod hqcrmrs128;
 pub mod hqcrmrs192;
